Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(188)

Unified Diff: gpu/command_buffer/service/in_process_command_buffer.h

Issue 1315713007: gpu: Reduce GL context switches used to check pending queries. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: gpu/command_buffer/service/in_process_command_buffer.h
diff --git a/gpu/command_buffer/service/in_process_command_buffer.h b/gpu/command_buffer/service/in_process_command_buffer.h
index b06a442555d465b947b6f32072495c9804830772..7c84db0e0b05603eb4bca092ad1ed4ad5f9679d7 100644
--- a/gpu/command_buffer/service/in_process_command_buffer.h
+++ b/gpu/command_buffer/service/in_process_command_buffer.h
@@ -139,9 +139,9 @@ class GPU_EXPORT InProcessCommandBuffer : public CommandBuffer,
// Queues a task to run as soon as possible.
virtual void ScheduleTask(const base::Closure& task) = 0;
// Schedules |callback| to run at an appropriate time for performing idle
// work.
- virtual void ScheduleIdleWork(const base::Closure& task) = 0;
+ virtual void ScheduleDelayedWork(const base::Closure& task) = 0;
virtual bool UseVirtualizedGLContexts() = 0;
virtual scoped_refptr<gles2::ShaderTranslatorCache>
@@ -200,7 +200,7 @@ class GPU_EXPORT InProcessCommandBuffer : public CommandBuffer,
bool InitializeOnGpuThread(const InitializeOnGpuThreadParams& params);
bool DestroyOnGpuThread();
void FlushOnGpuThread(int32 put_offset);
- void ScheduleIdleWorkOnGpuThread();
+ void ScheduleDelayedWorkOnGpuThread();
uint32 CreateStreamTextureOnGpuThread(uint32 client_texture_id);
bool MakeCurrent();
base::Closure WrapCallback(const base::Closure& callback);
@@ -226,7 +226,7 @@ class GPU_EXPORT InProcessCommandBuffer : public CommandBuffer,
void OnResizeView(gfx::Size size, float scale_factor);
bool GetBufferChanged(int32 transfer_buffer_id);
void PumpCommands();
- void PerformIdleWork();
+ void PerformDelayedWork();
// Members accessed on the gpu thread (possibly with the exception of
// creation):
@@ -237,7 +237,7 @@ class GPU_EXPORT InProcessCommandBuffer : public CommandBuffer,
scoped_refptr<gfx::GLContext> context_;
scoped_refptr<gfx::GLSurface> surface_;
base::Closure context_lost_callback_;
- bool idle_work_pending_; // Used to throttle PerformIdleWork.
+ bool delayed_work_pending_; // Used to throttle PerformDelayedWork.
ImageFactory* image_factory_;
// Members accessed on the client thread:
@@ -281,7 +281,7 @@ class GPU_EXPORT GpuInProcessThread
void AddRef() const override;
void Release() const override;
void ScheduleTask(const base::Closure& task) override;
- void ScheduleIdleWork(const base::Closure& callback) override;
+ void ScheduleDelayedWork(const base::Closure& callback) override;
bool UseVirtualizedGLContexts() override;
scoped_refptr<gles2::ShaderTranslatorCache> shader_translator_cache()
override;
@@ -139,9 +139,9 @@ class GPU_EXPORT InProcessCommandBuffer : public CommandBuffer,
// Queues a task to run as soon as possible.
virtual void ScheduleTask(const base::Closure& task) = 0;
- // Schedules |callback| to run at an appropriate time for performing idle
+ // Schedules |callback| to run at an appropriate time for performing delayed
// work.
« no previous file with comments | « gpu/command_buffer/service/gpu_scheduler.cc ('k') | gpu/command_buffer/service/in_process_command_buffer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698